NegativeKullbackLeiblerDivergence
=================================

.. currentmodule:: pykeen.nn.sim

.. autoclass:: NegativeKullbackLeiblerDivergence
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NegativeKullbackLeiblerDivergence.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
